"""
Omium TUI - Interactive Terminal User Interface.

This package provides an interactive TUI for managing Omium workflows and executions.
"""

from omium.tui.app import OmiumApp

__all__ = ["OmiumApp"]
